Method: RubyUnit::Assertions::Comparisons#assertGreaterThanOrEqual

Defined in:
lib/RubyUnit/Assertions/Comparisons.rb

#assertGreaterThanOrEqual(greater, value, message = nil) ⇒ Object

Assert that one value is greater than another.

  • raises RubyUnit::AssertionFailure unless greater is greater than or equal to value

greater

The value that should be greater than or equal

value

The value that is being checked by the assertion

message

The message provided to be reported for a failure

assertGreaterThanOrEqual 24, 42, "This will fail"  # => fail


81
82
83
# File 'lib/RubyUnit/Assertions/Comparisons.rb', line 81

def assertGreaterThanOrEqual greater, value, message = nil
  __assert (greater >= value), ASSERT_GREATERTHANOREQUAL_ERROR, message, {:greater=>greater, :value=>value}
end